@@ -1,4 +1,4 @@
-t1way <- function(formula, data, tr = 0.2) {
+t1way <- function(formula, data, tr = 0.2, nboot = 100) {
 
   if (missing(data)) {
     mf <- model.frame(formula)
@@ -18,6 +18,8 @@ t1way <- function(formula, data, tr = 0.2) {
   w <- vector("numeric",J)
   xbar <- vector("numeric",J)
   nv <- NA
+  
+  pts=NULL
   for(j in 1:J){
     xx <- !is.na(x[[j]])
     val <- x[[j]]
@@ -26,6 +28,8 @@ t1way <- function(formula, data, tr = 0.2) {
     h[j] <- length(x[[grp[j]]])-2*floor(tr*length(x[[grp[j]]]))
     w[j] <- h[j]*(h[j]-1)/((length(x[[grp[j]]])-1)*winvar(x[[grp[j]]],tr))
     xbar[j] <- mean(x[[grp[j]]],tr)
+    val<-elimna(val)
+    pts=c(pts,val)
  }
  u <- sum(w)
  xtil <- sum(w*xbar)/u
@@ -35,7 +39,30 @@ t1way <- function(formula, data, tr = 0.2) {
  nu1 <- J-1
  nu2 <- 1./(3*sum((1-w/u)^2/(h-1))/(J^2-1))
  sig <- 1-pf(TEST,nu1,nu2)
- result <- list(test = TEST, df1 =nu1, df2 = nu2, p.value = sig, call = cl)
+ 
+ 
+ 
+ chkn=var(nv)
+ if(chkn==0){
+   top=var(xbar)
+   bot=winvarN(pts,tr=tr)
+   e.pow=top/bot
+ }
+ if(chkn!=0){
+   vals=0
+   N=min(nv)
+   xdat=list()
+   for(i in 1:nboot){
+     for(j in 1:J){
+       xdat[[j]]=sample(x[[j]],N)
+     }
+     vals[i]=t1way.effect(xdat,tr=tr)$Var.Explained
+   }
+   loc.fun=median
+   e.pow=loc.fun(vals,na.rm=TRUE)
+ }
+ 
+ result <- list(test = TEST, df1 =nu1, df2 = nu2, p.value = sig, effsize = sqrt(e.pow), call = cl)
  class(result) <- c("t1way")
  result
 }
